<div align='center'>
<h1> MiV-OS: Spike Analysis and Computing Framework </h1>

[![License][badge-LICENSE]][link-LICENSE]
[![Release pypi][badge-pypi]][link-pypi]
[![Build Status][badge-CI]][link-CI]
[![Documentation Status][badge-docs-status]][link-docs-status]
[![Downloads][badge-pepy-download-count]][link-pepy-download-count]
[![codecov][badge-codecov]][link-codecov]

</div>

---

Python analysis and computing framework developed for [Mind-in-Vitro(MiV)][link-project-website] project.

## Installation
[![PyPI version][badge-pypi]][link-pypi]

MiV-OS is compatible with Python 3.8+. The easiest way to install is using python installation package (PIP)

~~~bash
$ pip install MiV-OS
~~~

## Documentation
[![Documentation Status][badge-docs-status]][link-docs-status]

Documentation of the package is available [here][link-docs-status]

## Contribution

If you would like to participate, please read our [contribution guideline](CONTRIBUTING.md)

The development of MiV-OS is lead by the [Gazzola Lab][link-lab-website] at the University of Illinois at Urbana-Champaign.

## List of publications and submissions

## Citation

```
@misc{MiV-OS,
  author = {Gazzola Lab},
  title = {MiV-OS: Analysis and Computation Framework on MiV System and Simulator},
  year = {2022},
  publisher = {GitHub},
  journal = {GitHub repository},
  howpublished = {\url{https://github.com/GazzolaLab/MiV-OS}},
}
```

We ask that any publications which use MiV-OS package to cite the following papers:

```
```

## Developers ✨
_Names arranged alphabetically_
- Arman Tekinalp
- Andrew Dou
- [Frithjof Gressmann](https://github.com/frthjf)
- Gaurav Upadhyay
- [Seung Hyun Kim](https://github.com/skim0119)

[//]: # (Collection of URLs.)

[link-lab-website]: http://mattia-lab.com/
[link-project-website]: https://mindinvitro.illinois.edu/
[link-docs-status]: https://miv-os.readthedocs.io/en/latest/?badge=latest
[link-CI]: https://github.com/GazzolaLab/MiV-OS/actions
[link-LICENSE]: https://opensource.org/licenses/MIT
[link-pypi]: https://badge.fury.io/py/MiV-OS
[link-pepy-download-count]: https://pepy.tech/project/MiV-OS
[link-codecov]: https://codecov.io/gh/GazzolaLab/MiV-OS

[//]: # (Collection of Badges)

[badge-docs-status]: https://readthedocs.org/projects/miv-os/badge/?version=latest
[badge-CI]: https://github.com/GazzolaLab/MiV-OS/workflows/CI/badge.svg
[badge-LICENSE]: https://img.shields.io/badge/License-MIT-yellow.svg
[badge-pypi]: https://badge.fury.io/py/MiV-OS.svg
[badge-pepy-download-count]: https://pepy.tech/badge/MiV-OS
[badge-codecov]: https://codecov.io/gh/GazzolaLab/MiV-OS/branch/main/graph/badge.svg?token=OM5LYWF5KP
